==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/MonthlyRecurrenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Monthly recurrence object.
 * @property daysOfMonth Specifies the values for monthly recurrence pattern.
 * @property endTime End time for recurrence.
 * @property recurrenceType Specifies when the recurrence should be applied.
 * Expected value is 'Monthly'.
 * @property startTime Start time for recurrence.
 */
public data class MonthlyRecurrenceArgs(
    public val daysOfMonth: Output<List<Int>>,
    public val endTime: Output<String>? = null,
    public val recurrenceType: Output<String>,
    public val startTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs.builder()
            .daysOfMonth(daysOfMonth.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .recurrenceType(recurrenceType.applyValue({ args0 -> args0 }))
            .startTime(startTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MonthlyRecurrenceArgs].
 */
@PulumiTagMarker
public class MonthlyRecurrenceArgsBuilder internal constructor() {
    private var daysOfMonth: Output<List<Int>>? = null

    private var endTime: Output<String>? = null

    private var recurrenceType: Output<String>? = null

    private var startTime: Output<String>? = null

    /**
     * @param value Specifies the values for monthly recurrence pattern.
     */
    @JvmName("qsnfnyremindbmku")
    public suspend fun daysOfMonth(`value`: Output<List<Int>>) {
        this.daysOfMonth = value
    }

    @JvmName("fhvnpakarpbvolju")
    public suspend fun daysOfMonth(vararg values: Output<Int>) {
        this.daysOfMonth = Output.all(values.asList())
    }

    /**
     * @param values Specifies the values for monthly recurrence pattern.
     */
    @JvmName("buqefhwxeooakdnr")
    public suspend fun daysOfMonth(values: List<Output<Int>>) {
        this.daysOfMonth = Output.all(values)
    }

    /**
     * @param value End time for recurrence.
     */
    @JvmName("nqafhcefqmqjnumk")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value Specifies when the recurrence should be applied.
     * Expected value is 'Monthly'.
     */
    @JvmName("hktjdymbkisccwgk")
    public suspend fun recurrenceType(`value`: Output<String>) {
        this.recurrenceType = value
    }

    /**
     * @param value Start time for recurrence.
     */
    @JvmName("mwlsrbjpwkklmeuj")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Specifies the values for monthly recurrence pattern.
     */
    @JvmName("wkankqtjhnvccjai")
    public suspend fun daysOfMonth(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.daysOfMonth = mapped
    }

    /**
     * @param values Specifies the values for monthly recurrence pattern.
     */
    @JvmName("xihauiqsbthvboge")
    public suspend fun daysOfMonth(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.daysOfMonth = mapped
    }

    /**
     * @param value End time for recurrence.
     */
    @JvmName("wviuwhndyhuigovf")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value Specifies when the recurrence should be applied.
     * Expected value is 'Monthly'.
     */
    @JvmName("xbsxfaoxqbyqinvf")
    public suspend fun recurrenceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recurrenceType = mapped
    }

    /**
     * @param value Start time for recurrence.
     */
    @JvmName("wbvnnwonpwsdyxvs")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    internal fun build(): MonthlyRecurrenceArgs = MonthlyRecurrenceArgs(
        daysOfMonth = daysOfMonth ?: throw PulumiNullFieldException("daysOfMonth"),
        endTime = endTime,
        recurrenceType = recurrenceType ?: throw PulumiNullFieldException("recurrenceType"),
        startTime = startTime,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/MonthlyRecurrenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Monthly recurrence object.
 * @property daysOfMonth Specifies the values for monthly recurrence pattern.
 * @property endTime End time for recurrence.
 * @property recurrenceType Specifies when the recurrence should be applied.
 * Expected value is 'Monthly'.
 * @property startTime Start time for recurrence.
 */
public data class MonthlyRecurrenceArgs(
    public val daysOfMonth: Output<List<Int>>,
    public val endTime: Output<String>? = null,
    public val recurrenceType: Output<String>,
    public val startTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs.builder()
            .daysOfMonth(daysOfMonth.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .recurrenceType(recurrenceType.applyValue({ args0 -> args0 }))
            .startTime(startTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MonthlyRecurrenceArgs].
 */
@PulumiTagMarker
public class MonthlyRecurrenceArgsBuilder internal constructor() {
    private var daysOfMonth: Output<List<Int>>? = null

    private var endTime: Output<String>? = null

    private var recurrenceType: Output<String>? = null

    private var startTime: Output<String>? = null

    /**
     * @param value Specifies the values for monthly recurrence pattern.
     */
    @JvmName("oxlxrsalpsskeety")
    public suspend fun daysOfMonth(`value`: Output<List<Int>>) {
        this.daysOfMonth = value
    }

    @JvmName("gxxjvfevqmpnrfns")
    public suspend fun daysOfMonth(vararg values: Output<Int>) {
        this.daysOfMonth = Output.all(values.asList())
    }

    /**
     * @param values Specifies the values for monthly recurrence pattern.
     */
    @JvmName("ejsoxeasdjrlfdiy")
    public suspend fun daysOfMonth(values: List<Output<Int>>) {
        this.daysOfMonth = Output.all(values)
    }

    /**
     * @param value End time for recurrence.
     */
    @JvmName("bsvuthggexkkmgym")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value Specifies when the recurrence should be applied.
     * Expected value is 'Monthly'.
     */
    @JvmName("epfomxuoassicxns")
    public suspend fun recurrenceType(`value`: Output<String>) {
        this.recurrenceType = value
    }

    /**
     * @param value Start time for recurrence.
     */
    @JvmName("lyqsaixxgofiqwos")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Specifies the values for monthly recurrence pattern.
     */
    @JvmName("beksactavyepbyio")
    public suspend fun daysOfMonth(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.daysOfMonth = mapped
    }

    /**
     * @param values Specifies the values for monthly recurrence pattern.
     */
    @JvmName("yelflrwtqrtytwxw")
    public suspend fun daysOfMonth(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.daysOfMonth = mapped
    }

    /**
     * @param value End time for recurrence.
     */
    @JvmName("udrpyvdijdnkkian")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value Specifies when the recurrence should be applied.
     * Expected value is 'Monthly'.
     */
    @JvmName("atwjssndmxvtlqps")
    public suspend fun recurrenceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recurrenceType = mapped
    }

    /**
     * @param value Start time for recurrence.
     */
    @JvmName("uxwovadlodyfkxaj")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    internal fun build(): MonthlyRecurrenceArgs = MonthlyRecurrenceArgs(
        daysOfMonth = daysOfMonth ?: throw PulumiNullFieldException("daysOfMonth"),
        endTime = endTime,
        recurrenceType = recurrenceType ?: throw PulumiNullFieldException("recurrenceType"),
        startTime = startTime,
    )
}
